@@ -1,12 +1,11 @@
 
 import math
 
-def haversine(lon1, lat1, lon2, lat2, log, r = 6371000):
+def haversine(lon1, lat1, lon2, lat2, r = 6371000):
     """
     Calculate the great circle distance in kilometers between two points
     on the earth (specified in decimal degrees)
     """
-    log = log.start_function("haversine")
 
     # convert decimal degrees to radians
     lon1, lat1, lon2, lat2 = map(math.radians, [lon1, lat1, lon2, lat2])
@@ -17,6 +16,4 @@ def haversine(lon1, lat1, lon2, lat2, log, r = 6371000):
     a = math.sin(dlat/2)**2 + math.cos(lat1) * math.cos(lat2) * math.sin(dlon/2)**2
     c = 2 * math.asin(math.sqrt(a))
 
-    log.close()
-
     return c * r
